Repository Structure — NeSy4PPM 0.1.0 documentation

# Repository Structure

- `NeSy4PPM/learning`: contains the implementation of event log encoding and Neural Networks model training.

- `NeSy4PPM/ProbDeclmonitor`: contains the implementation of suffix prediction using a contextualized Neural predictions with BK.

- `tests/`: provides evaluation scripts for assessing the NeSy4PPM prediction performance.

- `docs/tutorials/`: contains step-by-step guides and examples to help users get started with NeSy4PPM.